Positive

Struct Positive 

pub struct Positive<T>(/* private fields */);
Proof that a signed value is > 0.

Implementations

Source

impl Positive<i8>

pub fn new_ct(value: i8) -> CtOption<Positive<i8>>

Available on crate feature ct only.

Constant-time new: None-masked when value <= 0.

Source

impl Positive<i16>

pub fn new_ct(value: i16) -> CtOption<Positive<i16>>

Available on crate feature ct only.

Constant-time new: None-masked when value <= 0.

Source

impl Positive<i32>

pub fn new_ct(value: i32) -> CtOption<Positive<i32>>

Available on crate feature ct only.

Constant-time new: None-masked when value <= 0.

Source

impl Positive<i64>

pub fn new_ct(value: i64) -> CtOption<Positive<i64>>

Available on crate feature ct only.

Constant-time new: None-masked when value <= 0.

Source

impl Positive<i128>

pub fn new_ct(value: i128) -> CtOption<Positive<i128>>

Available on crate feature ct only.

Constant-time new: None-masked when value <= 0.

Source

impl Positive<isize>

pub fn new_ct(value: isize) -> CtOption<Positive<isize>>

Available on crate feature ct only.

Constant-time new: None-masked when value <= 0.

Source

impl Positive<i8>

pub const fn new(value: i8) -> Option<Self>

Some iff value > 0.

pub const unsafe fn new_unchecked(value: i8) -> Self

Safety

value must be > 0.

pub const fn get(self) -> i8

The proven value.

pub fn from_ref(value: &i8) -> Option<&Self>

Zero-cost borrowed proof (repr(transparent) reinterpret).

pub const fn to_unsigned(self) -> u8

Infallible cast to the unsigned counterpart.

pub const fn abs(self) -> i8

abs is the identity on a positive value.

pub const fn isqrt(self) -> i8

isqrt is total on a positive value.

pub const fn into_nonnegative(self) -> NonNegative<i8>

Positive ⊂ NonNegative.

pub const fn into_nonzero(self) -> NonZero<i8>

Positive ⊂ NonZero — narrows to core::num::NonZero with no recheck, so a Positive divisor can feed DivNonZero directly.

pub const fn into_nonmin(self) -> NonMin<i8>

Positive ⊂ NonMin (> 0, so != MIN).

Source

impl Positive<i16>

pub const fn new(value: i16) -> Option<Self>

Some iff value > 0.

pub const unsafe fn new_unchecked(value: i16) -> Self

Safety

value must be > 0.

pub const fn get(self) -> i16

The proven value.

pub fn from_ref(value: &i16) -> Option<&Self>

Zero-cost borrowed proof (repr(transparent) reinterpret).

pub const fn to_unsigned(self) -> u16

Infallible cast to the unsigned counterpart.

pub const fn abs(self) -> i16

abs is the identity on a positive value.

pub const fn isqrt(self) -> i16

isqrt is total on a positive value.

pub const fn into_nonnegative(self) -> NonNegative<i16>

Positive ⊂ NonNegative.

pub const fn into_nonzero(self) -> NonZero<i16>

Positive ⊂ NonZero — narrows to core::num::NonZero with no recheck, so a Positive divisor can feed DivNonZero directly.

pub const fn into_nonmin(self) -> NonMin<i16>

Positive ⊂ NonMin (> 0, so != MIN).

Source

impl Positive<i32>

pub const fn new(value: i32) -> Option<Self>

Some iff value > 0.

Examples found in repository?
examples/typestates.rs (line 69)
62fn signed_range() {
63    let nn = NonNegative::<i32>::new(81).expect("81 >= 0");
64    let u: u32 = nn.to_unsigned(); // infallible, bit-preserving
65    assert_eq!(u, 81);
66    assert_eq!(nn.isqrt(), 9); // total: input is known non-negative
67
68    // a positive value narrows straight into a NonZero divisor
69    let nz = Positive::<i32>::new(7).expect("7 > 0").into_nonzero();
70    assert_eq!(nz.get(), 7);
71}
72
73/// `NonMin`: a signed value proven `!= MIN` has total `abs`/`neg` and total
74/// signed division — the `MIN.abs()` and `MIN / -1` overflow cases are gone.
75fn nonmin() {
76    let a = NonMin::<i32>::new(-7).expect("-7 != MIN");
77    assert_eq!(a.abs(), 7); // no overflow branch
78    assert_eq!(a.neg(), 7);
79
80    // signed division by NonZero: MIN/-1 is impossible by construction
81    let d = core::num::NonZero::new(2).unwrap();
82    assert_eq!(a.div_nonzero(d), -7 / 2);
83
84    // Positive/NonNegative narrow into NonMin for free
85    let q = Positive::<i32>::new(9).unwrap().into_nonmin();
86    assert_eq!(q.abs(), 9);
87
88    assert!(NonMin::<i32>::new(i32::MIN).is_none());
89}
pub const unsafe fn new_unchecked(value: i32) -> Self

Safety

value must be > 0.

pub const fn get(self) -> i32

The proven value.

pub fn from_ref(value: &i32) -> Option<&Self>

Zero-cost borrowed proof (repr(transparent) reinterpret).

pub const fn to_unsigned(self) -> u32

Infallible cast to the unsigned counterpart.

pub const fn abs(self) -> i32

abs is the identity on a positive value.

pub const fn isqrt(self) -> i32

isqrt is total on a positive value.

pub const fn into_nonnegative(self) -> NonNegative<i32>

Positive ⊂ NonNegative.

pub const fn into_nonzero(self) -> NonZero<i32>

Positive ⊂ NonZero — narrows to core::num::NonZero with no recheck, so a Positive divisor can feed DivNonZero directly.

Examples found in repository?
examples/typestates.rs (line 69)
62fn signed_range() {
63    let nn = NonNegative::<i32>::new(81).expect("81 >= 0");
64    let u: u32 = nn.to_unsigned(); // infallible, bit-preserving
65    assert_eq!(u, 81);
66    assert_eq!(nn.isqrt(), 9); // total: input is known non-negative
67
68    // a positive value narrows straight into a NonZero divisor
69    let nz = Positive::<i32>::new(7).expect("7 > 0").into_nonzero();
70    assert_eq!(nz.get(), 7);
71}
pub const fn into_nonmin(self) -> NonMin<i32>

Positive ⊂ NonMin (> 0, so != MIN).

Examples found in repository?
examples/typestates.rs (line 85)
75fn nonmin() {
76    let a = NonMin::<i32>::new(-7).expect("-7 != MIN");
77    assert_eq!(a.abs(), 7); // no overflow branch
78    assert_eq!(a.neg(), 7);
79
80    // signed division by NonZero: MIN/-1 is impossible by construction
81    let d = core::num::NonZero::new(2).unwrap();
82    assert_eq!(a.div_nonzero(d), -7 / 2);
83
84    // Positive/NonNegative narrow into NonMin for free
85    let q = Positive::<i32>::new(9).unwrap().into_nonmin();
86    assert_eq!(q.abs(), 9);
87
88    assert!(NonMin::<i32>::new(i32::MIN).is_none());
89}
Source

impl Positive<i64>

pub const fn new(value: i64) -> Option<Self>

Some iff value > 0.

pub const unsafe fn new_unchecked(value: i64) -> Self

Safety

value must be > 0.

pub const fn get(self) -> i64

The proven value.

pub fn from_ref(value: &i64) -> Option<&Self>

Zero-cost borrowed proof (repr(transparent) reinterpret).

pub const fn to_unsigned(self) -> u64

Infallible cast to the unsigned counterpart.

pub const fn abs(self) -> i64

abs is the identity on a positive value.

pub const fn isqrt(self) -> i64

isqrt is total on a positive value.

pub const fn into_nonnegative(self) -> NonNegative<i64>

Positive ⊂ NonNegative.

pub const fn into_nonzero(self) -> NonZero<i64>

Positive ⊂ NonZero — narrows to core::num::NonZero with no recheck, so a Positive divisor can feed DivNonZero directly.

pub const fn into_nonmin(self) -> NonMin<i64>

Positive ⊂ NonMin (> 0, so != MIN).

Source

impl Positive<i128>

pub const fn new(value: i128) -> Option<Self>

Some iff value > 0.

pub const unsafe fn new_unchecked(value: i128) -> Self

Safety

value must be > 0.

pub const fn get(self) -> i128

The proven value.

pub fn from_ref(value: &i128) -> Option<&Self>

Zero-cost borrowed proof (repr(transparent) reinterpret).

pub const fn to_unsigned(self) -> u128

Infallible cast to the unsigned counterpart.

pub const fn abs(self) -> i128

abs is the identity on a positive value.

pub const fn isqrt(self) -> i128

isqrt is total on a positive value.

pub const fn into_nonnegative(self) -> NonNegative<i128>

Positive ⊂ NonNegative.

pub const fn into_nonzero(self) -> NonZero<i128>

Positive ⊂ NonZero — narrows to core::num::NonZero with no recheck, so a Positive divisor can feed DivNonZero directly.

pub const fn into_nonmin(self) -> NonMin<i128>

Positive ⊂ NonMin (> 0, so != MIN).

Source

impl Positive<isize>

pub const fn new(value: isize) -> Option<Self>

Some iff value > 0.

pub const unsafe fn new_unchecked(value: isize) -> Self

Safety

value must be > 0.

pub const fn get(self) -> isize

The proven value.

pub fn from_ref(value: &isize) -> Option<&Self>

Zero-cost borrowed proof (repr(transparent) reinterpret).

pub const fn to_unsigned(self) -> usize

Infallible cast to the unsigned counterpart.

pub const fn abs(self) -> isize

abs is the identity on a positive value.

pub const fn isqrt(self) -> isize

isqrt is total on a positive value.

pub const fn into_nonnegative(self) -> NonNegative<isize>

Positive ⊂ NonNegative.

pub const fn into_nonzero(self) -> NonZero<isize>

Positive ⊂ NonZero — narrows to core::num::NonZero with no recheck, so a Positive divisor can feed DivNonZero directly.

pub const fn into_nonmin(self) -> NonMin<isize>

Positive ⊂ NonMin (> 0, so != MIN).