pub trait WrappingAddSigned: Sized {
type Signed;
type Output;
// Required method
fn wrapping_add_signed(self, rhs: Self::Signed) -> Self::Output;
}Expand description
Wrapping (modular) addition of a signed value to an unsigned value.
Required Associated Types
Required Methods
Sourcefn wrapping_add_signed(self, rhs: Self::Signed) -> Self::Output
fn wrapping_add_signed(self, rhs: Self::Signed) -> Self::Output
Computes self + rhs, wrapping around at the boundary of the type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".