pub trait WrappingAddUnsigned: Sized {
type Unsigned;
type Output;
// Required method
fn wrapping_add_unsigned(self, rhs: Self::Unsigned) -> Self::Output;
}Expand description
Wrapping (modular) addition of an unsigned value to a signed value.
Required Associated Types
Required Methods
Sourcefn wrapping_add_unsigned(self, rhs: Self::Unsigned) -> Self::Output
fn wrapping_add_unsigned(self, rhs: Self::Unsigned) -> Self::Output
Computes self + rhs, wrapping around at the boundary of the type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".