pub trait WrappingSubUnsigned: Sized {
type Unsigned;
type Output;
// Required method
fn wrapping_sub_unsigned(self, rhs: Self::Unsigned) -> Self::Output;
}Expand description
Wrapping (modular) subtraction of an unsigned value from a signed value.
Required Associated Types
Required Methods
Sourcefn wrapping_sub_unsigned(self, rhs: Self::Unsigned) -> Self::Output
fn wrapping_sub_unsigned(self, rhs: Self::Unsigned) -> Self::Output
Computes self - rhs, wrapping around at the boundary of the type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".